@@ -999,6 +999,14 @@ class Test:
           "first second third fourth fifth")],
           "['fourth fifth', 'second third']")
 
+        self.expect(lambda: regex.search("abcdef", "abcdef").span(), "(0, 6)")
+        self.expect(lambda: regex.search("(?r)abcdef", "abcdef").span(),
+          "(0, 6)")
+        self.expect(lambda: regex.search("(?i)abcdef", "ABCDEF").span(),
+          "(0, 6)")
+        self.expect(lambda: regex.search("(?ir)abcdef", "ABCDEF").span(),
+          "(0, 6)")
+
     def test_atomic(self):
         # Issue 433030.
         self.expect(lambda: regex.search(r"(?>a*)a", "aa"), "None")
